<?php

namespace ACL\Controllers;

use ACL\Traits\TResponse;
use Exception;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use ACL\Helpers\Instances\InstanceProvider;
use ACL\Util\AclUtilities;
use ACL\Services\Perfilacesso as PerfilDeAcessoService;

class Perfilacesso {

    use TResponse;

    /**
     * @var PerfilDeAcessoService
     */
    private $perfilacessoService;

    public function __construct(PerfilDeAcessoService $perfilacessoService)
    {
        $this->perfilacessoService = $perfilacessoService;
    }

    public function findAllPerfilacesso(Request $request, Response $response)
    {
        try{
            $data = $this->perfilacessoService->findAllPerfilacesso();
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function createPerfilacesso(Request $request, Response $response)
    {
        try{
            $perfisDeAcesso = $request->getParameters();
            $nmperfilacesso = $request->getParameter('NMPERFILACESSO');
            $idperfilacessoadm = $request->getParameter('IDPERFILACESSOADM');
            $idativo = $request->getParameter('IDATIVO');
            $labels = $perfisDeAcesso['aclNextLabelsTraductionLog'][0];
            $data = $this->perfilacessoService->createPerfilacesso($nmperfilacesso, $idperfilacessoadm, $idativo, $labels);
            $this->sendResponse($data, 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    /**
     * @param Request $request
     * @param Response $response
     * @throws \Doctrine\DBAL\Driver\Exception
     */
    public function updatePerfilacesso(Request $request, Response $response)
    {
        try{
            $perfisDeAcesso = $request->getParameters();
            $labels = $perfisDeAcesso[0]['aclNextLabelsTraductionLog'][0];
            $this->perfilacessoService->updatePerfilacesso($perfisDeAcesso, $labels);
            $this->sendResponse(null, 204);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deletePerfilacesso(Request $request, Response $response)
    {
        try{
            $perfisDeAcesso = $request->getParameter('rows');
            $labels = $request->getParameter('aclNextLabelsTraductionLog')[0];
            $this->perfilacessoService->deletePerfilacesso($perfisDeAcesso, $labels);
            $this->sendResponse([], 200);
        }catch(Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findAccessControlUtilization(Request $request, Response $response)
    {
        try {
            $data = $this->perfilacessoService->findAccessControlUtilization();
            $this->sendResponse($data, 200);
        } catch (Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findPerfilacessoByOperador(Request $request)
    {
        try {
            $idativo = $request->getParameter('IDATIVO');
            $nrparcnegocio = $request->getParameter('NRPARCNEGOCIO');
            $data = $this->perfilacessoService->findPerfilacessoByOperador($idativo, $nrparcnegocio);
            $this->sendResponse($data, 200);
        } catch (Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findPerfilAcessoForAddOperador(Request $request)
    {
        try {
            $nrparcnegocio = $request->getParameter('NRPARCNEGOCIO');
            $data = $this->perfilacessoService->findPerfilAcessoForAddOperador($nrparcnegocio);
            $this->sendResponse($data, 200);
        } catch (Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }
}
