<?php

namespace ACL\Services;

use ACL\Helpers\Instances\InstanceProvider;
use ACL\Repositories\OperadorLabelVersao as OperadorLabelVersaoRepository;
use ACL\Traits\TCrud;
use Exception;
use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DependencyInjection\InstanceManager;

class OperadorLabelVersao
{

    use TCrud;

    /**
     * @var Environment
     */
    private $libEnvironment;
    /**
     * @var OperadorLabelVersaoRepository
     */
    private $operadorLabelVersaoRepository;

    /**
     * @throws Exception
     */
    public function __construct()
    {
        $this->libEnvironment = InstanceProvider::getLibEnvironment();
        $this->operadorLabelVersaoRepository = InstanceProvider::getRepository()->getOperadorLabelVersao();
    }

    /**
     * @throws Exception
     */
    public function findByOperadorAndProject(): array
    {
        $productId = InstanceManager::getInstance()->getParameter('projectId');
        return $this->operadorLabelVersaoRepository->findByOperadorAndProject($productId, getCurrentUserId(), getNrorg());
    }

    /**
     * @param $version
     * @throws \Doctrine\DBAL\Exception|\Doctrine\DBAL\Driver\Exception
     */
    public function save($version)
    {
        $productId = InstanceManager::getInstance()->getParameter('projectId');
        $data = $this->operadorLabelVersaoRepository->findByOperadorAndProject($productId, getCurrentUserId(), getNrorg());
        if (empty($data)) {
            $newCode = InstanceProvider::getNewCode()->getCodeByTableName('OPERADOR_LABEL_VERSAO', getNrorg(), 1, 10, true);
            $this->operadorLabelVersaoRepository
                ->createByOperadorAndProject($newCode, $productId, getCurrentUserId(), $version, getNrorg(), 'S', getCurrentUserId());
        } else {
            $this->operadorLabelVersaoRepository->updateVersion($data[0]['ID'], $version, getNrorg(), getCurrentUserId());
        }
    }
}
