<?php

namespace ACL\Services;

use ACL\Helpers\Instances\InstanceProvider;
use ACL\Repositories\Perfilacesso as PerfilDeAcessoRepository;
use ACL\Util\AclUtilities;
use Exception;

class Perfilacesso {

    /**
     * @var \Teknisa\Libs\Util\Environment
     */
    private $libEnvironment;

    /**
     * @var PerfilDeAcessoRepository
     */
    private $perfilacessoRepository;

    public function __construct(PerfilDeAcessoRepository $perfilacessoRepository)
    {
        $this->perfilacessoRepository = $perfilacessoRepository;
        $this->libEnvironment =  InstanceProvider::getLibEnvironment();
    }

    /**
     * @return array
     */
    public function findAllPerfilacesso(): array
    {
        $organizationId = InstanceProvider::getLibEnvironment()->getCurrentOrganizationId();
        return $this->perfilacessoRepository->findAllPerfilacesso($organizationId);
    }

    /**
     * @param $nmperfilacesso
     * @param $idperfilacessoadm
     * @param $idativo
     * @return array
     */
    public function createPerfilacesso($nmperfilacesso, $idperfilacessoadm, $idativo, $labels): array
    {
        $newCode = InstanceProvider::getNewCode();
        $organizationId = $this->libEnvironment->getCurrentOrganizationId();
        $newNrperfilacesso = $newCode->getCodeByTableName('PERFILACESSO', $organizationId);
        $this->perfilacessoRepository->createPerfilacesso($newNrperfilacesso, $nmperfilacesso, $idperfilacessoadm, $idativo);
        $valores = [$labels['label'], $newNrperfilacesso, $nmperfilacesso, $idperfilacessoadm, $idativo];
        $nomes = ["Tela", 'NRPERFILACESSO', $labels['NMPERFILACESSO'], $labels['IDPERFILACESSOADM'], $labels['IDATIVO']];
        $descricao = AclUtilities::gerarDescricao($valores, $nomes);
        InstanceProvider::getLibLog()->logRegister($newNrperfilacesso, $descricao, '1', 'PERFILACESSO', '/perfilacesso');
        return ['NRPERFILACESSO' => $newNrperfilacesso];
    }

    /**
     * @param $perfisDeAcesso
     * @throws \Doctrine\DBAL\Driver\Exception
     * @throws \Doctrine\DBAL\Exception
     */
    public function updatePerfilacesso($perfisDeAcesso, $labels)
    {
        foreach ($perfisDeAcesso as $perfil) {
            $perfilAntigo =  $this->perfilacessoRepository->findValAntigoPerfAcess($perfil['NRPERFILACESSO']);
            $arrayValores = [$labels['label']];
            $arrayNomes = ['Tela'];
            if ($perfilAntigo[0]['NMPERFILACESSO'] !== $perfil['NMPERFILACESSO']) {
                array_push($arrayValores, $perfil['NMPERFILACESSO']);
                array_push($arrayNomes, $labels['NMPERFILACESSO']);
            }
            if ($perfilAntigo[0]['IDPERFILACESSOADM'] !== $perfil['IDPERFILACESSOADM']) {
                array_push($arrayValores, $perfil['IDPERFILACESSOADM']);
                array_push($arrayNomes, $labels['IDPERFILACESSOADM']);
            }
            if ($perfilAntigo[0]['IDATIVO'] !== $perfil['IDATIVO']) {
                array_push($arrayValores, $perfil['IDATIVO']);
                array_push($arrayNomes, $labels['IDATIVO']);
            }
            $descricao = AclUtilities::gerarDescricao($arrayValores, $arrayNomes);
            InstanceProvider::getLibLog()->logRegister($perfil['NRPERFILACESSO'], $descricao, '2', 'PERFILACESSO', '/perfilacesso');
            $this->perfilacessoRepository->updatePerfilacesso($perfil['NRPERFILACESSO'], $perfil['NMPERFILACESSO'],
                                                                $perfil['IDPERFILACESSOADM'], $perfil['IDATIVO']);
        }
    }

    public function deletePerfilacesso($perfisDeAcesso, $labels)
    {
        foreach ($perfisDeAcesso as $perfil) {
            $this->perfilacessoRepository->deletePerfilacesso($perfil['NRPERFILACESSO']);
            $valores = [$labels['label'], $perfil['NRPERFILACESSO']];
            $nomes = ["Tela", $labels['NRPERFILACESSO']];
            $descricao = AclUtilities::gerarDescricao($valores, $nomes);
            InstanceProvider::getLibLog()->logRegister($perfil['NRPERFILACESSO'], $descricao, '3', 'PERFILACESSO', '/perfilacesso');
        }
    }

    /**
     * @return array[]
     * @throws Exception
     */
    public function findAccessControlUtilization()
    {
        $organizationId = $this->libEnvironment->getCurrentOrganizationId();
        $data = array('NRORG' => $organizationId, 'CDOPERADOR' => getCurrentUserId());
        $accessControlUtilization = $this->perfilacessoRepository->findAccessControlUtilization($organizationId);
        if (!empty($accessControlUtilization)) {
            $data = array_merge($accessControlUtilization[0], $data);
        }
        return $data;
    }

    /**
     * @param $idativo
     * @param $nrparcnegocio
     * @return array
     * @throws Exception
     */
    public function findPerfilacessoByOperador($idativo, $nrparcnegocio): array
    {
        return $this->perfilacessoRepository->findPerfilacessoByOperador(getNrorg(), $idativo, $nrparcnegocio);
    }

    /**
     * @param $nrparcnegocio
     * @return array|mixed[]
     * @throws Exception
     */
    public function findPerfilAcessoForAddOperador($nrparcnegocio): array
    {
        return $this->perfilacessoRepository->findPerfilAcessoForAddOperador(getNrorg(), $nrparcnegocio);
    }
}
