/* eslint-disable */
import { Http, Metadata, Interceptor, I18n } from '@zeedhi/core';
import { LoadingService } from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { PmLibUtil } from '@zeedhi/pm-lib';
import * as jsonData from './aclNextLabelsTraductionLog.json';

export class Utilities {
	public static getNameDynamic(name: string) {
		const date = new Date();
		return name + date.getTime();
	}

	public static async validateNovocodigo() {
		await Http.post('/novocodigo/validate');
	}

	public static getOnlyNumberInString(string: string) {
		if (string) {
			return string.split(/\D+/).join('');
		}
		return '';
	}

	public static fill(value: any, length: any, toRight: any, filler: any) {
		if (value) {
			value = value.toString();

			if (filler) {
				filler = filler.toString()[0];
			} else {
				filler = '0';
			}

			if (toRight) {
				while (value.length + filler.length <= length) {
					value += filler;
				}
			} else {
				while (value.length + filler.length <= length) {
					value = filler + value;
				}
			}
		}
		return value;
	}

	public static clone(jsonObject: any) {
		return JSON.parse(JSON.stringify(jsonObject));
	}

	public static async timeout(time: number) {
		return new Promise((resolve) => setTimeout(resolve, time));
	}

	public static async doAsync(callBack: Function, time: number) {
		return new Promise((resolve) => {
			this.timeout(time).then(() => {
				callBack();
				resolve();
			});
		});
	}

	public static async setLoadingByTime(time: number) {
		LoadingService.show();
		await this.timeout(time);
		LoadingService.hide();
	}

	public static dynamicFilterLog(gridName: string, content: any) {
		console.log(`%cDynamic Filter ${gridName}`, 'color: blue');
		console.log(content);
	}

	public static async getInstanceTekGrid(name: string): Promise<any> {
		try {
			return Metadata.getInstance<TekGrid>(name);
		} catch (e) {
			await PmLibUtil.timeout(500);
			return this.getInstanceTekGrid(name);
		}
	}
}

Interceptor.addRequestSuccess((config) => {
	if (config.data) {
		const aclNextLabelsTraductionLog: any = [];
		// Iterar sobre cada rótulo
		jsonData.labelsNext.forEach((label): any => {
			if (label.rota === config.url) {
				const translatedLabel: any = {};
				// Iterar sobre cada propriedade do rótulo
				Object.keys(label).forEach((key) => {
					const value = label[key as keyof typeof label];
					// Verificar se o valor é uma string e não está vazio
					if (typeof value === 'string' && value.trim() !== '') {
						// Traduzir o valor usando o serviço I18n e atribuir ao novo rótulo
						translatedLabel[key as keyof typeof label] = I18n.translate(value);
					} else {
						// Se o valor não for uma string ou estiver vazio, copiar o valor original
						translatedLabel[key as keyof typeof label] = value;
					}
				});
				aclNextLabelsTraductionLog.push(translatedLabel);
			}
		});
		if (Array.isArray(config.data)) {
			config.data[0].aclNextLabelsTraductionLog = aclNextLabelsTraductionLog;
		} else {
			config.data.aclNextLabelsTraductionLog = aclNextLabelsTraductionLog;	
		}
	}
	return config;
});
